==> jc-1.4.0.tar.gz: gnu/xml/util/SAXNullTransformerFactory__24DomTerminus.h <==
// class gnu.xml.util.SAXNullTransformerFactory$DomTerminus

// class file dependencies
// @dep_class dd1504d5138e45 gnu_xml_pipeline_DomConsumer
// @dep_class 48368fff555d2019 gnu_xml_util_SAXNullTransformerFactory__24DomTerminus
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_DomConsumer

#include "gnu/xml/pipeline/DomConsumer.h"

#ifndef _JC_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus_H_
#define _JC_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_transform_dom_DOMResult$object;

// Typedefs
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$object	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$object;

typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$fields_struct	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$fields_struct;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vmethods	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vmethods;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtable	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtable;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtype	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtype;

// Class fields structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24xml__24dom__24DomDocument;
};
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$fields_struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$class_fields;

// Constructors
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$method$_init$cae7f83ab03a9669(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$object *, struct _jc_javax_xml_transform_dom_DOMResult$object *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vmethods {
};

// Vtable
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_DomConsumer$vmethods	gnu_xml_pipeline_DomConsumer;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vmethods	gnu_xml_util_SAXNullTransformerFactory__24DomTerminus;
};

// Vtype
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$refs {
    _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_refs	gnu_xml_util_SAXNullTransformerFactory__24DomTerminus;
    _jc_gnu_xml_pipeline_DomConsumer$sub_refs	gnu_xml_pipeline_DomConsumer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_DomConsumer$sub_nonrefs	gnu_xml_pipeline_DomConsumer;
    _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_nonrefs	gnu_xml_util_SAXNullTransformerFactory__24DomTerminus;
};

// Object instance structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$object {
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtype	*vtype;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtype _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_SAXNullTransformerFactory__24DomTerminus, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$class_object;

#endif	/* _JC_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/util/SAXNullTransformerFactory__24DomTerminus.h <==
// class gnu.xml.util.SAXNullTransformerFactory$DomTerminus

// class file dependencies
// @dep_class dd1504d5138e45 gnu_xml_pipeline_DomConsumer
// @dep_class 48368fff555d2019 gnu_xml_util_SAXNullTransformerFactory__24DomTerminus
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_DomConsumer

#include "gnu/xml/pipeline/DomConsumer.h"

#ifndef _JC_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus_H_
#define _JC_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_transform_dom_DOMResult$object;

// Typedefs
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$object	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$object;

typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$fields_struct	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$fields_struct;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vmethods	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vmethods;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtable	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtable;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtype	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtype;

// Class fields structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24xml__24dom__24DomDocument;
};
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$fields_struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$class_fields;

// Constructors
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$method$_init$cae7f83ab03a9669(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$object *, struct _jc_javax_xml_transform_dom_DOMResult$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vmethods {
};

// Vtable
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_DomConsumer$vmethods	gnu_xml_pipeline_DomConsumer;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vmethods	gnu_xml_util_SAXNullTransformerFactory__24DomTerminus;
};

// Vtype
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$refs {
    _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_refs	gnu_xml_util_SAXNullTransformerFactory__24DomTerminus;
    _jc_gnu_xml_pipeline_DomConsumer$sub_refs	gnu_xml_pipeline_DomConsumer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_DomConsumer$sub_nonrefs	gnu_xml_pipeline_DomConsumer;
    _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$sub_nonrefs	gnu_xml_util_SAXNullTransformerFactory__24DomTerminus;
};

// Object instance structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$object {
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtype	*vtype;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$vtype _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_SAXNullTransformerFactory__24DomTerminus, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus$class_object;

#endif	/* _JC_gnu_xml_util_SAXNullTransformerFactory__24DomTerminus_H_ */
